# Motorized Devices Control

[![PyPI - Version](https://img.shields.io/pypi/v/eksma-optics-md-control.svg)](https://pypi.org/project/eksma-optics-md-control)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/eksma-optics-md-control.svg)](https://pypi.org/project/eksma-optics-md-control)

Motorized Devices Control is an interactive application for controlling EKSMA Optics motorized devices.

## Getting Started

### Installation

```shell
pip install eksma-optics-md-control
```

### Usage

```shell
mdcontrol
```

## License

MIT
